@@ -1,6 +1,6 @@
 package List::Objects::WithUtils::Role::Array;
 {
-  $List::Objects::WithUtils::Role::Array::VERSION = '1.004000';
+  $List::Objects::WithUtils::Role::Array::VERSION = '1.005000';
 }
 use strictures 1;
 
@@ -39,12 +39,14 @@ sub copy {
   bless [ @{ $_[0] } ], blessed_or_pkg($_[0])
 }
 
+sub all { @{ $_[0] } }
+
 sub count { CORE::scalar @{ $_[0] } }
+
 { no warnings 'once'; *scalar = *count; *export = *all; }
 
 sub is_empty { CORE::scalar @{ $_[0] } ? 0 : 1 }
 
-sub all { @{ $_[0] } }
 sub get { $_[0]->[ $_[1] ] }
 sub set { $_[0]->[ $_[1] ] = $_[2] ; $_[0] }
 
@@ -111,13 +113,12 @@ sub grep {
 }
 
 sub sort {
-  my @sorted;
   if (defined $_[1]) {
-    @sorted = CORE::sort {; $_[1]->($a, $b) } @{ $_[0] }
-  } else {
-    @sorted = CORE::sort @{ $_[0] }
+    return blessed_or_pkg($_[0])->new(
+      CORE::sort {; $_[1]->($a, $b) } @{ $_[0] }
+    )
   }
-  blessed_or_pkg($_[0])->new(@sorted)
+  return blessed_or_pkg($_[0])->new( CORE::sort @{ $_[0] } )
 }
 
 sub reverse {
